@@ -45,6 +45,8 @@ __all__ = (
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
     "ChannelTypeDef",
+    "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
+    "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
     "CreateChannelRequestRequestTypeDef",
     "CreateChannelResponseTypeDef",
     "CreateProgramRequestRequestTypeDef",
@@ -94,6 +96,7 @@ __all__ = (
     "ListVodSourcesRequestRequestTypeDef",
     "ListVodSourcesResponseTypeDef",
     "LivePreRollConfigurationTypeDef",
+    "LogConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PaginatorConfigTypeDef",
     "PlaybackConfigurationTypeDef",
@@ -216,6 +219,23 @@ class ChannelTypeDef(_RequiredChannelTypeDef, _OptionalChannelTypeDef):
     pass
 
 
+ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
+    {
+        "PercentEnabled": int,
+        "PlaybackConfigurationName": str,
+    },
+)
+
+ConfigureLogsForPlaybackConfigurationResponseTypeDef = TypedDict(
+    "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
+    {
+        "PercentEnabled": int,
+        "PlaybackConfigurationName": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateChannelRequestRequestTypeDef = TypedDict(
     "_RequiredCreateChannelRequestRequestTypeDef",
     {
@@ -611,6 +631,7 @@ GetPlaybackConfigurationResponseTypeDef = TypedDict(
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
         "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "LogConfiguration": "LogConfigurationTypeDef",
         "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
@@ -797,6 +818,13 @@ LivePreRollConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+LogConfigurationTypeDef = TypedDict(
+    "LogConfigurationTypeDef",
+    {
+        "PercentEnabled": int,
+    },
+)
+
 ManifestProcessingRulesTypeDef = TypedDict(
     "ManifestProcessingRulesTypeDef",
     {
@@ -826,6 +854,7 @@ PlaybackConfigurationTypeDef = TypedDict(
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
         "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "LogConfiguration": "LogConfigurationTypeDef",
         "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
@@ -880,6 +909,7 @@ PutPlaybackConfigurationResponseTypeDef = TypedDict(
         "DashConfiguration": "DashConfigurationTypeDef",
         "HlsConfiguration": "HlsConfigurationTypeDef",
         "LivePreRollConfiguration": "LivePreRollConfigurationTypeDef",
+        "LogConfiguration": "LogConfigurationTypeDef",
         "ManifestProcessingRules": "ManifestProcessingRulesTypeDef",
         "Name": str,
         "PersonalizationThresholdSeconds": int,
